@@ -1,4 +1,6 @@
-pub mod http_error;
-pub mod read_error;
+//! error module.
+
+mod http_error;
+mod read_error;
 pub use http_error::*;
 pub use read_error::ReadError;
